diff --git a/res/res_pjsip/pjsip_options.c b/res/res_pjsip/pjsip_options.c
index a7aefaa565..5de25bb417 100644
--- a/res/res_pjsip/pjsip_options.c
+++ b/res/res_pjsip/pjsip_options.c
@@ -1585,6 +1585,7 @@ static int sip_options_synchronize_endpoint(void *obj, void *arg, int flags)
 {
 	struct ast_sip_endpoint *endpoint = obj;
 	struct ast_sip_aor *aor = arg;
+	int found = 0;
 	char *aors;
 	char *aor_name;
 	struct sip_options_endpoint_compositor_task_data task_data = { NULL, };
@@ -1611,6 +1612,8 @@ static int sip_options_synchronize_endpoint(void *obj, void *arg, int flags)
 			continue;
 		}
 
+		found = 1;
+
 		task_data.aor_options = ao2_find(sip_options_aors, aor_name, OBJ_SEARCH_KEY);
 		if (!task_data.aor_options) {
 			/*
@@ -1655,24 +1658,26 @@ static int sip_options_synchronize_endpoint(void *obj, void *arg, int flags)
 		}
 	}
 
-	if (task_data.endpoint_state_compositor) {
-		/*
-		 * If an endpoint state compositor is present determine the current state
-		 * of the endpoint and update it.
-		 */
-		ao2_lock(task_data.endpoint_state_compositor);
-		task_data.endpoint_state_compositor->active = 1;
-		ast_sip_persistent_endpoint_update_state(ast_sorcery_object_get_id(endpoint),
-			sip_options_get_endpoint_state_compositor_state(task_data.endpoint_state_compositor));
-		ao2_unlock(task_data.endpoint_state_compositor);
-
-		ao2_ref(task_data.endpoint_state_compositor, -1);
-	} else {
-		/* If there is none then they may have referenced an invalid AOR or none at all */
-		ast_debug(3, "Endpoint '%s' has no AORs feeding it, setting it to offline state as default\n",
-			ast_sorcery_object_get_id(endpoint));
-		ast_sip_persistent_endpoint_update_state(ast_sorcery_object_get_id(endpoint),
-			AST_ENDPOINT_OFFLINE);
+	if (found) {
+		if (task_data.endpoint_state_compositor) {
+			/*
+			 * If an endpoint state compositor is present determine the current state
+			 * of the endpoint and update it.
+			 */
+			ao2_lock(task_data.endpoint_state_compositor);
+			task_data.endpoint_state_compositor->active = 1;
+			ast_sip_persistent_endpoint_update_state(ast_sorcery_object_get_id(endpoint),
+				sip_options_get_endpoint_state_compositor_state(task_data.endpoint_state_compositor));
+			ao2_unlock(task_data.endpoint_state_compositor);
+	
+			ao2_ref(task_data.endpoint_state_compositor, -1);
+		} else {
+			/* If there is none then they may have referenced an invalid AOR or none at all */
+			ast_debug(3, "Endpoint '%s' has no AORs feeding it, setting it to offline state as default\n",
+				ast_sorcery_object_get_id(endpoint));
+			ast_sip_persistent_endpoint_update_state(ast_sorcery_object_get_id(endpoint),
+				AST_ENDPOINT_OFFLINE);
+		}
 	}
 
 	return 0;
